"""
Linear Regression
"""


class LinearRegression:
    """
    Based on Ordinary Least Square Method
    """

    def __init__(self):
        self.x_train = []
        self.predictions = []

    def fit(self, x_train, y_train):
        pass

    def predict(self, x_test):
        return self.predictions
